summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codeimport/nativeimportbase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
commit4ae0c208b66e0f7954e194384464fe2d0a2c56dd (patch)
treeb0a7cd1c184f0003c0292eb416ed27f674f9cc43 /umbrello/umbrello/codeimport/nativeimportbase.h
parent1964ea0fb4ab57493ca2ebb709c8d3b5395fd653 (diff)
downloadtdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.tar.gz
tdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1157652 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/codeimport/nativeimportbase.h')
-rw-r--r--umbrello/umbrello/codeimport/nativeimportbase.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/umbrello/umbrello/codeimport/nativeimportbase.h b/umbrello/umbrello/codeimport/nativeimportbase.h
index cc82fd91..03a78a5c 100644
--- a/umbrello/umbrello/codeimport/nativeimportbase.h
+++ b/umbrello/umbrello/codeimport/nativeimportbase.h
@@ -12,8 +12,8 @@
#ifndef NATIVEIMPORTBASE_H
#define NATIVEIMPORTBASE_H
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
#include "classimport.h"
#include "../umlnamespace.h"
@@ -47,7 +47,7 @@ public:
* Constructor
* @param singleLineCommentIntro "//" for IDL and Java, "--" for Ada
*/
- NativeImportBase(const QString &singleLineCommentIntro);
+ NativeImportBase(const TQString &singleLineCommentIntro);
virtual ~NativeImportBase();
protected:
@@ -64,12 +64,12 @@ protected:
* @param end In languages with a C style multiline comment
* this is star-slash.
*/
- void setMultiLineComment(const QString &intro, const QString &end);
+ void setMultiLineComment(const TQString &intro, const TQString &end);
/**
* Set the delimiter strings for an alternative form of
* multi line comment. See setMultiLineComment().
*/
- void setMultiLineAltComment(const QString &intro, const QString &end);
+ void setMultiLineAltComment(const TQString &intro, const TQString &end);
/**
* Import a single file.
@@ -78,12 +78,12 @@ protected:
*
* @param filename The file to import.
*/
- virtual void parseFile(const QString& filename);
+ virtual void parseFile(const TQString& filename);
/**
* Initialize auxiliary variables.
* This is called by the default implementation of parseFile()
* after scanning (before parsing the QStringList m_source.)
* The default implementation is empty.
*/
virtual void initVars();
@@ -95,7 +95,7 @@ protected:
*
* @param line The line to scan.
*/
- void scan(QString line);
+ void scan(TQString line);
/**
* Preprocess a line.
@@ -108,21 +108,21 @@ protected:
* false if there are still items left in the line
* for further analysis.
*/
- virtual bool preprocess(QString& line);
+ virtual bool preprocess(TQString& line);
/**
* Split the line so that a string is returned as a single element of the list.
* When not in a string then split at white space.
* The default implementation is suitable for C style strings and char constants.
*/
- virtual QStringList split(const QString& line);
+ virtual TQStringList split(const TQString& line);
/**
* Analyze the given word and fill `m_source'.
* A "word" is a whitespace delimited item from the input line.
* To be provided by the specific importer class.
*/
- virtual void fillSource(const QString& word) = 0;
+ virtual void fillSource(const TQString& word) = 0;
/**
* Parse the statement which starts at m_source[m_srcIndex]
@@ -138,7 +138,7 @@ protected:
* Advance m_srcIndex until m_source[m_srcIndex] contains the lexeme
* given by `until'.
*/
- void skipStmt(QString until = ";");
+ void skipStmt(TQString until = ";");
/**
* Advance m_srcIndex to the index of the corresponding closing character
@@ -148,24 +148,24 @@ protected:
* @return True for success, false for misuse (invalid opener) or
* if no matching closing character is found in m_source.
*/
- bool skipToClosing(QChar opener);
+ bool skipToClosing(TQChar opener);
/**
* Advance m_srcIndex until m_source[m_srcIndex] contains a non-comment.
* Comments encountered during advancement are accumulated in `m_comment'.
* If m_srcIndex hits the end of m_source then QString::null is returned.
*/
- QString advance();
+ TQString advance();
/**
* How to start a single line comment in this programming language.
*/
- QString m_singleLineCommentIntro;
+ TQString m_singleLineCommentIntro;
/**
* The scanned lexemes.
*/
- QStringList m_source;
+ TQStringList m_source;
/**
* Used for indexing m_source.
*/
@@ -191,7 +191,7 @@ protected:
/**
* Intermediate accumulator for comment text.
*/
- QString m_comment;
+ TQString m_comment;
/**
* True if we are currently in a multi-line comment.
* Only applies to languages with multi-line comments.
@@ -208,19 +208,19 @@ protected:
* whether the name is already present in this list in order to
* avoid parsing the same file multiple times.
*/
- QStringList m_parsedFiles;
+ TQStringList m_parsedFiles;
/**
* Multi line comment delimiters
*/
- QString m_multiLineCommentIntro;
- QString m_multiLineCommentEnd;
+ TQString m_multiLineCommentIntro;
+ TQString m_multiLineCommentEnd;
/**
* Some languages support an alternative set of multi line
* comment delimiters.
*/
- QString m_multiLineAltCommentIntro;
- QString m_multiLineAltCommentEnd;
+ TQString m_multiLineAltCommentIntro;
+ TQString m_multiLineAltCommentEnd;
};
#endif
@@ -78,12 +78,12 @@ protected:
* Initialize auxiliary variables.
* This is called by the default implementation of parseFile()
- * after scanning (before parsing the QStringList m_source.)
+ * after scanning (before parsing the TQStringList m_source.)
* The default implementation is empty.
*/
@@ -148,24 +148,24 @@ protected:
* Advance m_srcIndex until m_source[m_srcIndex] contains a non-comment.
* Comments encountered during advancement are accumulated in `m_comment'.
- * If m_srcIndex hits the end of m_source then QString::null is returned.
+ * If m_srcIndex hits the end of m_source then TQString::null is returned.
*/